summaryrefslogtreecommitdiff
path: root/test/lisp/net
diff options
context:
space:
mode:
authorMichael Albinus <michael.albinus@gmx.de>2023-01-13 19:35:52 +0100
committerMichael Albinus <michael.albinus@gmx.de>2023-01-13 19:35:52 +0100
commit9f8f8ed1bafba97ac942ee03645fa60c67fdfce7 (patch)
tree65264aad612594bec5ffb69aae69e490a796dd0d /test/lisp/net
parent861556c1339cd65842ec3e24ba48590e6b72bd48 (diff)
downloademacs-9f8f8ed1bafba97ac942ee03645fa60c67fdfce7.tar.gz
emacs-9f8f8ed1bafba97ac942ee03645fa60c67fdfce7.tar.bz2
emacs-9f8f8ed1bafba97ac942ee03645fa60c67fdfce7.zip
Adapt tramp-tests.el (do not merge with master)
* test/lisp/net/tramp-tests.el (tramp--test-container-p): Rename from `tramp--test-docker-p'. Handle also "podman" method. Adapt callees.
Diffstat (limited to 'test/lisp/net')
-rw-r--r--test/lisp/net/tramp-tests.el19
1 files changed, 11 insertions, 8 deletions
diff --git a/test/lisp/net/tramp-tests.el b/test/lisp/net/tramp-tests.el
index a3d7d9f656b..0f21e3a45eb 100644
--- a/test/lisp/net/tramp-tests.el
+++ b/test/lisp/net/tramp-tests.el
@@ -5504,7 +5504,7 @@ INPUT, if non-nil, is a string sent to the process."
(format "%s\n" (file-name-nondirectory tmp-name)))
(should
(string-match-p
;; Some shells echo, for example the "adb" or "docker" methods.
(tramp-compat-rx
bos (** 1 2 (literal (file-name-nondirectory tmp-name)) "\n")
eos)
@@ -6637,11 +6637,12 @@ This is used in tests which we don't want to tag
"Check, whether the remote directory is encrypted."
(tramp-crypt-file-name-p ert-remote-temporary-file-directory))
-(defun tramp--test-docker-p ()
- "Check, whether the docker method is used.
+(defun tramp--test-container-p ()
+ "Check, whether a container method is used.
This does not support some special file names."
- (string-equal
- "docker" (file-remote-p ert-remote-temporary-file-directory 'method)))
+ (string-match-p
+ (rx bol (| "docker" "podman") eol)
+ (file-remote-p ert-remote-temporary-file-directory 'method)))
(defun tramp--test-expensive-test-p ()
"Whether expensive tests are run.
@@ -7026,7 +7027,7 @@ This requires restrictions of file name syntax."
(let ((files
(list
(cond ((or (tramp--test-ange-ftp-p)
- (tramp--test-docker-p)
+ (tramp--test-container-p)
(tramp--test-gvfs-p)
(tramp--test-rclone-p)
(tramp--test-sudoedit-p)
@@ -7084,7 +7085,7 @@ This requires restrictions of file name syntax."
"Check UTF8 encoding in file names and file contents."
(skip-unless (tramp--test-enabled))
(skip-unless (not (getenv "EMACS_HYDRA_CI"))) ; SLOW ~ 620s
- (skip-unless (not (tramp--test-docker-p)))
+ (skip-unless (not (tramp--test-container-p)))
(skip-unless (not (tramp--test-rsync-p)))
(skip-unless (not (tramp--test-windows-nt-and-out-of-band-p)))
(skip-unless (not (tramp--test-ksh-p)))
@@ -7213,7 +7214,7 @@ process sentinels. They shall not disturb each other."
;; remote processes in Emacs. That doesn't work for tramp-adb.el.
(when (tramp--test-adb-p)
(skip-unless (tramp--test-emacs27-p)))
- (skip-unless (not (tramp--test-docker-p)))
+ (skip-unless (not (tramp--test-container-p)))
(skip-unless (not (tramp--test-telnet-p)))
(skip-unless (not (tramp--test-sshfs-p)))
(skip-unless (not (tramp--test-windows-nt-p)))
@@ -7703,6 +7704,8 @@ If INTERACTIVE is non-nil, the tests are run interactively."
;; * file-equal-p (partly done in `tramp-test21-file-links')
;; * file-in-directory-p
;; * file-name-case-insensitive-p
+;; * memory-info
+;; * tramp-get-home-directory
;; * tramp-get-remote-gid
;; * tramp-get-remote-groups
;; * tramp-get-remote-uid
@@ -5504,7 +5504,7 @@ INPUT, if non-nil, is a string sent to the process."
(should
(string-match-p
- ;; Some shells echo, for example the "adb" or "docker" methods.
+ ;; Some shells echo, for example the "adb" or container methods.
(tramp-compat-rx
bos (** 1 2 (literal (file-name-nondirectory tmp-name)) "\n")